==> typedi-0.0.1.tgz: package/Container.js <==
require('reflect-metadata');
var Container = (function () {
    function Container() {
    }
    // -------------------------------------------------------------------------
    // Public Static Methods
    // -------------------------------------------------------------------------
    Container.registerRequireParam = function (cls, index, packageName) {
        this.requireParams.push({ type: cls, index: index, packageName: packageName });
    };
    Container.get = function (type, params) {
        var obj = this.findInstanceOfType(type);
        if (obj)
            return obj;
        if (params) {
            params = this.mapParams(type, params);
            params.unshift(null);
        }
        var objectInstance = new (type.bind.apply(type, params))();
        this.instances.push({ type: type, instance: objectInstance });
        return objectInstance;
    };
    // -------------------------------------------------------------------------
    // Private Static Methods
    // -------------------------------------------------------------------------
    Container.findInstanceOfType = function (type) {
        return this.instances.reduce(function (found, typeInstance) { return typeInstance.type === type ? typeInstance.instance : found; }, null);
    };
    Container.findRequireParams = function (type, index) {
        return this.requireParams.reduce(function (found, param) { return param.type === type && param.index === index ? param : found; }, null);
    };
    Container.mapParams = function (type, params) {
        var _this = this;
        return params.map(function (param, key) {
            var requireParam = _this.findRequireParams(type, key);
            if (requireParam)
                return require(requireParam.packageName);
            return Container.get(param, Reflect.getMetadata('design:paramtypes', param));
        });
    };
    // -------------------------------------------------------------------------
    // Static Properties
    // -------------------------------------------------------------------------
    Container.instances = [];
    Container.requireParams = [];
    return Container;
})();
exports.Container = Container;

==> typedi-0.0.4.tgz: package/Container.js <==
require('reflect-metadata');
var Container = (function () {
    function Container() {
    }
    // -------------------------------------------------------------------------
    // Public Static Methods
    // -------------------------------------------------------------------------
    Container.registerCustomParamHandler = function (paramHandler) {
        this.customParamHandlers.push(paramHandler);
    };
    Container.get = function (type, params) {
        var obj = this.findInstanceOfType(type);
        if (obj)
            return obj;
        if (params) {
            params = this.mapParams(type, params);
            params.unshift(null);
        }
        var objectInstance = new (type.bind.apply(type, params))();
        this.instances.push({ type: type, instance: objectInstance });
        return objectInstance;
    };
    // -------------------------------------------------------------------------
    // Private Static Methods
    // -------------------------------------------------------------------------
    Container.findInstanceOfType = function (type) {
        return this.instances.reduce(function (found, typeInstance) { return typeInstance.type === type ? typeInstance.instance : found; }, null);
    };
    Container.findCustomParamHandler = function (type, index) {
        return this.customParamHandlers.reduce(function (found, param) { return param.type === type && param.index === index ? param : found; }, null);
    };
    Container.mapParams = function (type, params) {
        var _this = this;
        return params.map(function (param, key) {
            var paramHandler = _this.findCustomParamHandler(type, key);
            if (paramHandler)
                return paramHandler.getValue();
            return Container.get(param, Reflect.getMetadata('design:paramtypes', param));
        });
    };
    // -------------------------------------------------------------------------
    // Static Properties
    // -------------------------------------------------------------------------
    Container.instances = [];
    Container.customParamHandlers = [];
    return Container;
})();
exports.Container = Container;
